@@ -1,21 +1,24 @@
-################################################################################
+#!/usr/bin/env python
+# encoding: utf-8
 #
-#    Copyright 2015-2020 Félix Brezo and Yaiza Rubio
+##################################################################################
 #
-#    This program is part of OSRFramework. You can redistribute it and/or modify
-#    it under the terms of the GNU Affero General Public License as published by
+#    Copyright 2015 Félix Brezo and Yaiza Rubio (i3visio, contacto@i3visio.com)
+#
+#    This file is part of OSRFramework. You can redistribute it and/or modify
+#    it under the terms of the GNU General Public License as published by
 #    the Free Software Foundation, either version 3 of the License, or
 #    (at your option) any later version.
 #
 #    This program is distributed in the hope that it will be useful,
 #    but WITHOUT ANY WARRANTY; without even the implied warranty of
 #    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-#    GNU Affero General Public License for more details.
+#    GNU General Public License for more details.
 #
-#    You should have received a copy of the GNU Affero General Public License
+#    You should have received a copy of the GNU General Public License
 #    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-################################################################################
+##################################################################################
 
 import argparse
 import json
@@ -481,7 +484,7 @@ class TwitterAPIWrapper(APIWrapper):
                     except:
                         # Error... We will have to wait
                         waiting = True
-                        print("No more queries remaining, sleeping for " + str(waitTime) +" seconds...")
+                        print "No more queries remaining, sleeping for " + str(waitTime) +" seconds..."
                         time.sleep(waitTime)  """
 
                 new_tweets = _getNewTweets(api, screen_name, oldest=oldest)
@@ -738,6 +741,7 @@ class TwitterAPIWrapper(APIWrapper):
 
         page = 0
 
+        # print "Getting page %s of new users..." % page+1
         # Making the call to the API
         try:
             newUsers = api.search_users(query, n, page)
