@@ -1,6 +1,6 @@
 ################################################################################
 #
-#    Copyright 2015-2020 Félix Brezo and Yaiza Rubio
+#    Copyright 2015-2021 Félix Brezo and Yaiza Rubio
 #
 #    This program is part of OSRFramework. You can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -18,7 +18,7 @@
 ################################################################################
 
 __author__ = "Felix Brezo, Yaiza Rubio  <contacto@i3visio.com>"
-__version__ = "3.0"
+__version__ = "3.1"
 
 
 from osrframework.utils.platforms import Platform
@@ -40,7 +40,7 @@ class Minds(Platform):
                     "com.i3visio.Name": '<h2>([^<]+)</h2>',
                 },
                 "needs_credentials": False,
-                "not_found_text": "Sorry, the channel couldn't be found",
+                "not_found_text": "this user could not be found",
                 "query_validator": "[a-z0-9A-Z_]+",
                 "url": "https://www.minds.com/{placeholder}",
             }
